{% load i18n %} {% if not schedule.changes.count %} {% if schedule.changes.action == 'update' %}

{{ phrases.agenda.changelog_unchanged }}

{% else %}

{{ phrases.agenda.changelog_first }}

{% endif %} {% else %} {% if schedule.changes.new_talks|length > 0 %} {% if schedule.changes.new_talks|length > 1 %}

{{ phrases.agenda.changelog_new_talks }}

{% for talk in schedule.changes.new_talks %}
- {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talks.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }} {% endif %}
{% endfor %}

{% else %}

{{ phrases.agenda.changelog_new_talk }} {% for talk in schedule.changes.new_talks %} {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talk.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }} {% endif %} . {% endfor %} {% endif %}

{% endif %} {% if schedule.changes.canceled_talks|length > 0 %} {% if schedule.changes.canceled_talks|length > 1 %}

{{ phrases.agenda.changelog_canceled_talks }}

{% for talk in schedule.changes.canceled_talks %}
- {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talk.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }} {% endif %}
{% endfor %}

{% else %}

{{ phrases.agenda.changelog_canceled_talk }} {% for talk in schedule.changes.canceled_talks %} {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talk.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }}. {% endif %} {% endfor %}

{% endif %} {% endif %} {% if schedule.changes.moved_talks|length > 0 %} {% if schedule.changes.moved_talks|length > 1 %}

{{ phrases.agenda.changelog_moved_talks }}

{% for talk in schedule.changes.moved_talks %}
- {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talk.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }} {% endif %} {% if talk.old_room == talk.new_room %} ({{ talk.old_start }} → {{ talk.new_start }}) {% elif talk.old_start == talk.new_start %} ({{ talk.old_room }} → {{ talk.new_room }}) {% else %} ({{ talk.old_start }}, {{ talk.old_room }} → {{ talk.new_start }}, {{ talk.new_room }}) {% endif %}
{% endfor %}

{% else %}

{{ phrases.agenda.changelog_moved_talk }} {% for talk in schedule.changes.moved_talks %} {{ quotation_open }}{{ talk.submission.title }}{{ quotation_close }} {% if talk.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }} {% endif %} {% if talk.old_room == talk.new_room %} ({{ talk.old_start }} → {{ talk.new_start }}) {% elif talk.old_start == talk.new_start %} ({{ talk.old_room }} → {{ talk.new_room }}) {% else %} ({{ talk.old_start }}, {{ talk.old_room }} → {{ talk.new_start }}, {{ talk.new_room }}). {% endif %} {% endfor %}

{% endif %} {% endif %} {% endif %}